import React from 'react';
import type { ListRowProps } from 'react-virtualized';
import type { IRemoteOptions } from '../Hooks/useRemote';
import type { ICacheOptions } from '../Hooks/useCache';
import { IHighlightOptions } from '../Addon/HighlightAddon';
import type { SearcherRef } from '../Addon/WorkerLog/types';
import { VirtualDomTerminal, TerminalRef, ExtraOptions, LogAfterProps } from '../types';
import './index.less';
export interface TerminalViewerVirtualDomProps {
    /**
     * @description.zh-CN 是否自动拉伸填充容器宽高
     * @default true
     */
    fit?: boolean;
    /**
     * @description.zh-CN 外层样式类名
     */
    className?: string;
    /**
     * @description.zh-CN 自定义空文本显示
     */
    empty?: React.ReactNode;
    /**
     *@description.zh-CN 是否开启自动滚动到底部
     *@default true
     */
    autoScroll?: boolean;
    /**
     * @description.zh-CN 自动滚动到某一行，开启后自动滚动到底部失效
     */
    scrollToRow?: number;
    /**
     * @description.zh-CN 设置日志后置标签，仅在开启虚拟 DOM 生效
     */
    logAfter?: React.FunctionComponent<LogAfterProps> | React.ComponentClass<LogAfterProps>;
    /**
     * @description.zh-CN 用于渲染日志的默认数据，如 "echo 1\r\necho2"
     * @default '''
     */
    defaultData?: string;
    /**
     * @description.zh-CN 远程搜索配置
     *
     */
    remoteOptions?: IRemoteOptions;
    /**
     * @description.zh-CN 缓存配置，仅在配置远程加载后有效，如 `expires: 60 * 1000` 表示自动清理已过期一分钟的缓存
     */
    cacheOptions?: ICacheOptions;
    /**
     * @description.zh-CN 高亮选项
     */
    highlightOptions?: IHighlightOptions[];
    /**
     * @description.zh-CN 额外的功能选项 { showLineNumber 仅 虚拟 DOM 模式支持}
     */
    extraOptions?: ExtraOptions;
    /**
     * @description.zh-CN 插件加载成功后的回调
     */
    onAddonReady?: (instance?: VirtualDomTerminal, addon?: SearcherRef) => void;
    /**
     * @description.zh-CN 加载状态变更后的回调
     */
    onLoading?: (loading: boolean) => void;
}
export type RowRenderProps = ListRowProps & {
    style: object;
};
declare const TerminalViewerVirtualDom: React.ForwardRefExoticComponent<TerminalViewerVirtualDomProps & React.RefAttributes<TerminalRef | undefined>>;
export default TerminalViewerVirtualDom;
